# Copyright (c) 2020 Ultimaker B.V.
# Cura is released under the terms of the LGPLv3 or higher.

CuraAppName = "cura"
CuraAppDisplayName = "Ultimaker Cura"
CuraVersion = "4.6.2"
CuraBuildType = ""
CuraDebugMode = True if "" == "ON" else False
CuraCloudAPIRoot = "https://api.ultimaker.com"
CuraCloudAPIVersion = "1"
CuraCloudAccountAPIRoot = "https://account.ultimaker.com"
CuraMarketplaceRoot = ""
